diff --git a/account_financial_report_qweb/reports.xml b/account_financial_report_qweb/reports.xml
index 29116dea..7d1e8230 100644
--- a/account_financial_report_qweb/reports.xml
+++ b/account_financial_report_qweb/reports.xml
@@ -21,12 +21,12 @@
/>
-
+
diff --git a/account_financial_report_qweb/wizard/__init__.py b/account_financial_report_qweb/wizard/__init__.py
index 5df33995..d2268190 100644
--- a/account_financial_report_qweb/wizard/__init__.py
+++ b/account_financial_report_qweb/wizard/__init__.py
@@ -1,8 +1,9 @@
# -*- coding: utf-8 -*-
# Author: Damien Crier
+# Author: Julien Coux
# Copyright 2016 Camptocamp SA
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
from . import aged_partner_balance_wizard
from . import balance_common_wizard
from . import general_ledger_wizard
-from . import open_invoice_wizard
+from . import open_items_wizard
diff --git a/account_financial_report_qweb/wizard/open_invoice_wizard_view.xml b/account_financial_report_qweb/wizard/open_items_wizard_view.xml
similarity index 78%
rename from account_financial_report_qweb/wizard/open_invoice_wizard_view.xml
rename to account_financial_report_qweb/wizard/open_items_wizard_view.xml
index 60487b3f..30ee1ab2 100644
--- a/account_financial_report_qweb/wizard/open_invoice_wizard_view.xml
+++ b/account_financial_report_qweb/wizard/open_items_wizard_view.xml
@@ -2,10 +2,10 @@
-
-
- Open Invoice
- open.invoice.report.wizard
+
+
+ Open Items
+ open.items.report.wizard
-
- Open Invoice
+
+ Open Items
ir.actions.act_window
- open.invoice.report.wizard
+ open.items.report.wizard
form
form
-
+
new
diff --git a/account_financial_report_qweb/wizard/open_invoice_wizard.py b/account_financial_report_qweb/wizard/open_items_wizard.py
similarity index 90%
rename from account_financial_report_qweb/wizard/open_invoice_wizard.py
rename to account_financial_report_qweb/wizard/open_items_wizard.py
index 90b374f9..9b930856 100644
--- a/account_financial_report_qweb/wizard/open_invoice_wizard.py
+++ b/account_financial_report_qweb/wizard/open_items_wizard.py
@@ -8,11 +8,11 @@ from datetime import datetime
from openerp import models, fields, api
-class OpenInvoiceReportWizard(models.TransientModel):
- """Open invoice report wizard."""
+class OpenItemsReportWizard(models.TransientModel):
+ """Open items report wizard."""
- _name = "open.invoice.report.wizard"
- _description = "Open Invoice Report Wizard"
+ _name = "open.items.report.wizard"
+ _description = "Open Items Report Wizard"
company_id = fields.Many2one(
comodel_name='res.company',
@@ -69,7 +69,12 @@ class OpenInvoiceReportWizard(models.TransientModel):
@api.multi
def button_export_pdf(self):
- model = self.env['report_open_invoice_qweb']
+ self.ensure_one()
+ return self._export()
+
+ def _export(self):
+ """Default export is PDF."""
+ model = self.env['report_open_items_qweb']
report = model.create({
'date_at': self.date_at,
'only_posted_moves': self.target_move == 'posted',